pub enum DeciderKind {
Automatic,
Human,
__Unknown(i64),
}Expand description
DeciderKind : What produced a decision on an access request, as it appears on the wire: 0 = automatic, 1 = human. What produced a decision on an access request, as it appears on the
wire: 0 = automatic, 1 = human.
Variants
Automatic
Human
__Unknown(i64)
Unknown value returned from the server. This is used to handle forward compatibility.
Implementations